# HG changeset patch
# Node ID bae24213e7c7
# Parent  ee44db31a1e3
diff --git a/pidgin/gtkconv.c b/pidgin/gtkconv.c
--- a/pidgin/gtkconv.c
+++ b/pidgin/gtkconv.c
@@ -1745,7 +1745,7 @@
 	}
 
 	win = gtk_widget_get_root(gtkconv->tab_cont);
-	pidgin_conversation_window_remove(PIDGIN_CONVERSATION_WINDOW(win), conv);
+	pidgin_display_window_remove(PIDGIN_DISPLAY_WINDOW(win), conv);
 
 	/* If the "Save Conversation" or "Save Icon" dialogs are open then close them */
 	purple_request_close_with_handle(gtkconv);
@@ -2012,9 +2012,9 @@
 
 	win = gtk_widget_get_root(gtkconv->tab_cont);
 	if(gtk_window_is_active(GTK_WINDOW(win))) {
-		PidginConversationWindow *convwin = PIDGIN_CONVERSATION_WINDOW(win);
-
-		if(pidgin_conversation_window_conversation_is_selected(convwin, conv)) {
+		PidginDisplayWindow *displaywin = PIDGIN_DISPLAY_WINDOW(win);
+
+		if(pidgin_display_window_conversation_is_selected(displaywin, conv)) {
 			return TRUE;
 		}
 	}
@@ -2026,7 +2026,7 @@
 pidgin_conv_update_fields(PurpleConversation *conv, PidginConvFields fields)
 {
 	PidginConversation *gtkconv;
-	PidginConversationWindow *convwin;
+	PidginDisplayWindow *displaywin;
 	GtkRoot *win;
 
 	gtkconv = PIDGIN_CONVERSATION(conv);
@@ -2034,7 +2034,7 @@
 		return;
 
 	win = gtk_widget_get_root(gtkconv->tab_cont);
-	convwin = PIDGIN_CONVERSATION_WINDOW(win);
+	displaywin = PIDGIN_DISPLAY_WINDOW(win);
 
 	if (fields & PIDGIN_CONV_SET_TITLE)
 	{
@@ -2110,7 +2110,7 @@
 		if (title != markup)
 			g_free(markup);
 
-		if (pidgin_conversation_window_conversation_is_selected(convwin, conv)) {
+		if (pidgin_display_window_conversation_is_selected(displaywin, conv)) {
 			const char* current_title = gtk_window_get_title(GTK_WINDOW(win));
 			if (current_title == NULL || !purple_strequal(current_title, title)) {
 				gtk_window_set_title(GTK_WINDOW(win), title);
@@ -2743,10 +2743,10 @@
 static void
 pidgin_conv_placement_place(PidginConversation *conv) {
 	GtkWidget *window = NULL;
-	PidginConversationWindow *conv_window = NULL;
-
-	window = pidgin_conversation_window_get_default();
-	conv_window = PIDGIN_CONVERSATION_WINDOW(window);
-
-	pidgin_conversation_window_add(conv_window, conv->active_conv);
+	PidginDisplayWindow *display_window = NULL;
+
+	window = pidgin_display_window_get_default();
+	display_window = PIDGIN_DISPLAY_WINDOW(window);
+
+	pidgin_display_window_add(display_window, conv->active_conv);
 }
diff --git a/pidgin/pidginapplication.c b/pidgin/pidginapplication.c
--- a/pidgin/pidginapplication.c
+++ b/pidgin/pidginapplication.c
@@ -889,7 +889,7 @@
 
 static void
 pidgin_application_activate(GApplication *application) {
-	GtkWidget *convwin = pidgin_conversation_window_get_default();
+	GtkWidget *convwin = pidgin_display_window_get_default();
 
 	if(GTK_IS_WINDOW(convwin)) {
 		gtk_window_present(GTK_WINDOW(convwin));
diff --git a/pidgin/pidginconversationwindow.c b/pidgin/pidginconversationwindow.c
--- a/pidgin/pidginconversationwindow.c
+++ b/pidgin/pidginconversationwindow.c
@@ -30,10 +30,10 @@
 #include "pidgininvitedialog.h"
 
 enum {
-	PIDGIN_CONVERSATION_WINDOW_COLUMN_OBJECT,
-	PIDGIN_CONVERSATION_WINDOW_COLUMN_NAME,
-	PIDGIN_CONVERSATION_WINDOW_COLUMN_ICON,
-	PIDGIN_CONVERSATION_WINDOW_COLUMN_MARKUP,
+	PIDGIN_DISPLAY_WINDOW_COLUMN_OBJECT,
+	PIDGIN_DISPLAY_WINDOW_COLUMN_NAME,
+	PIDGIN_DISPLAY_WINDOW_COLUMN_ICON,
+	PIDGIN_DISPLAY_WINDOW_COLUMN_MARKUP,
 };
 
 enum {
@@ -42,7 +42,7 @@
 };
 static guint signals[N_SIGNALS] = {0, };
 
-struct _PidginConversationWindow {
+struct _PidginDisplayWindow {
 	GtkApplicationWindow parent;
 
 	GtkWidget *vbox;
@@ -58,7 +58,7 @@
 	GtkTreePath *conversation_path;
 };
 
-G_DEFINE_TYPE(PidginConversationWindow, pidgin_conversation_window,
+G_DEFINE_TYPE(PidginDisplayWindow, pidgin_display_window,
               GTK_TYPE_APPLICATION_WINDOW)
 
 static GtkWidget *default_window = NULL;
@@ -67,9 +67,9 @@
  * Helpers
  *****************************************************************************/
 static void
-pidgin_conversation_window_actions_set_enabled(GActionMap *map,
-                                               const gchar **actions,
-                                               gboolean enabled)
+pidgin_display_window_actions_set_enabled(GActionMap *map,
+                                          const gchar **actions,
+                                          gboolean enabled)
 {
 	gint i = 0;
 
@@ -90,8 +90,8 @@
  * Callbacks
  *****************************************************************************/
 static void
-pidgin_conversation_window_invite_cb(GtkDialog *dialog, gint response_id,
-                                     G_GNUC_UNUSED gpointer data)
+pidgin_display_window_invite_cb(GtkDialog *dialog, gint response_id,
+                                G_GNUC_UNUSED gpointer data)
 {
 	PidginInviteDialog *invite_dialog = PIDGIN_INVITE_DIALOG(dialog);
 	PurpleChatConversation *chat = NULL;
@@ -123,14 +123,14 @@
  * Actions
  *****************************************************************************/
 static void
-pidgin_conversation_window_alias(G_GNUC_UNUSED GSimpleAction *simple,
-                                 G_GNUC_UNUSED GVariant *parameter,
-                                 gpointer data)
+pidgin_display_window_alias(G_GNUC_UNUSED GSimpleAction *simple,
+                            G_GNUC_UNUSED GVariant *parameter,
+                            gpointer data)
 {
-	PidginConversationWindow *window = data;
+	PidginDisplayWindow *window = data;
 	PurpleConversation *selected = NULL;
 
-	selected = pidgin_conversation_window_get_selected(window);
+	selected = pidgin_display_window_get_selected(window);
 	if(PURPLE_IS_CONVERSATION(selected)) {
 		PurpleAccount *account;
 		const gchar *name;
@@ -155,29 +155,29 @@
 }
 
 static void
-pidgin_conversation_window_close_conversation(G_GNUC_UNUSED GSimpleAction *simple,
-                                              G_GNUC_UNUSED GVariant *parameter,
-                                              gpointer data)
+pidgin_display_window_close_conversation(G_GNUC_UNUSED GSimpleAction *simple,
+                                         G_GNUC_UNUSED GVariant *parameter,
+                                         gpointer data)
 {
-	PidginConversationWindow *window = data;
+	PidginDisplayWindow *window = data;
 	PurpleConversation *selected = NULL;
 
-	selected = pidgin_conversation_window_get_selected(window);
+	selected = pidgin_display_window_get_selected(window);
 	if(PURPLE_IS_CONVERSATION(selected)) {
-		pidgin_conversation_window_remove(window, selected);
+		pidgin_display_window_remove(window, selected);
 		pidgin_conversation_detach(selected);
 	}
 }
 
 static void
-pidgin_conversation_window_get_info(G_GNUC_UNUSED GSimpleAction *simple,
-                                    G_GNUC_UNUSED GVariant *parameter,
-                                    gpointer data)
+pidgin_display_window_get_info(G_GNUC_UNUSED GSimpleAction *simple,
+                               G_GNUC_UNUSED GVariant *parameter,
+                               gpointer data)
 {
-	PidginConversationWindow *window = data;
+	PidginDisplayWindow *window = data;
 	PurpleConversation *selected = NULL;
 
-	selected = pidgin_conversation_window_get_selected(window);
+	selected = pidgin_display_window_get_selected(window);
 	if(PURPLE_IS_CONVERSATION(selected)) {
 		if(PURPLE_IS_IM_CONVERSATION(selected)) {
 			PurpleConnection *connection = NULL;
@@ -190,14 +190,14 @@
 }
 
 static void
-pidgin_conversation_window_invite(G_GNUC_UNUSED GSimpleAction *simple,
-                                  G_GNUC_UNUSED GVariant *parameter,
-                                  gpointer data)
+pidgin_display_window_invite(G_GNUC_UNUSED GSimpleAction *simple,
+                             G_GNUC_UNUSED GVariant *parameter,
+                             gpointer data)
 {
-	PidginConversationWindow *window = data;
+	PidginDisplayWindow *window = data;
 	PurpleConversation *selected = NULL;
 
-	selected = pidgin_conversation_window_get_selected(window);
+	selected = pidgin_display_window_get_selected(window);
 	if(PURPLE_IS_CHAT_CONVERSATION(selected)) {
 		GtkWidget *invite_dialog = NULL;
 
@@ -214,7 +214,7 @@
 			gtk_window_set_destroy_with_parent(GTK_WINDOW(invite_dialog), TRUE);
 
 			g_signal_connect(invite_dialog, "response",
-			                 G_CALLBACK(pidgin_conversation_window_invite_cb),
+			                 G_CALLBACK(pidgin_display_window_invite_cb),
 			                 NULL);
 		}
 
@@ -223,14 +223,14 @@
 }
 
 static void
-pidgin_conversation_window_send_file(G_GNUC_UNUSED GSimpleAction *simple,
-                                     G_GNUC_UNUSED GVariant *parameter,
-                                     gpointer data)
+pidgin_display_window_send_file(G_GNUC_UNUSED GSimpleAction *simple,
+                                G_GNUC_UNUSED GVariant *parameter,
+                                gpointer data)
 {
-	PidginConversationWindow *window = data;
+	PidginDisplayWindow *window = data;
 	PurpleConversation *selected = NULL;
 
-	selected = pidgin_conversation_window_get_selected(window);
+	selected = pidgin_display_window_get_selected(window);
 	if(PURPLE_IS_IM_CONVERSATION(selected)) {
 		PurpleConnection *connection = NULL;
 
@@ -244,40 +244,40 @@
 static GActionEntry win_entries[] = {
 	{
 		.name = "alias",
-		.activate = pidgin_conversation_window_alias
+		.activate = pidgin_display_window_alias
 	}, {
 		.name = "close",
-		.activate = pidgin_conversation_window_close_conversation
+		.activate = pidgin_display_window_close_conversation
 	}, {
 		.name = "get-info",
-		.activate = pidgin_conversation_window_get_info
+		.activate = pidgin_display_window_get_info
 	}, {
 		.name = "invite",
-		.activate = pidgin_conversation_window_invite
+		.activate = pidgin_display_window_invite
 	}, {
 		.name = "send-file",
-		.activate = pidgin_conversation_window_send_file
+		.activate = pidgin_display_window_send_file
 	}
 };
 
 /*<private>
- * pidgin_conversation_window_conversation_actions:
+ * pidgin_display_window_conversation_actions:
  *
  * A list of action names that are only valid if a conversation is selected.
  */
-static const gchar *pidgin_conversation_window_conversation_actions[] = {
+static const gchar *pidgin_display_window_conversation_actions[] = {
 	"alias",
 	"close",
 	"get-info",
 	NULL
 };
 
-static const gchar *pidgin_conversation_window_im_conversation_actions[] = {
+static const gchar *pidgin_display_window_im_conversation_actions[] = {
 	"send-file",
 	NULL
 };
 
-static const gchar *pidgin_conversation_window_chat_conversation_actions[] = {
+static const gchar *pidgin_display_window_chat_conversation_actions[] = {
 	"invite",
 	NULL
 };
@@ -286,10 +286,10 @@
  * Callbacks
  *****************************************************************************/
 static void
-pidgin_conversation_window_selection_changed(GtkTreeSelection *selection,
-                                             gpointer data)
+pidgin_display_window_selection_changed(GtkTreeSelection *selection,
+                                        gpointer data)
 {
-	PidginConversationWindow *window = PIDGIN_CONVERSATION_WINDOW(data);
+	PidginDisplayWindow *window = PIDGIN_DISPLAY_WINDOW(data);
 	GtkTreeModel *model = NULL;
 	GtkTreeIter iter;
 	gboolean changed = FALSE;
@@ -301,8 +301,8 @@
 		gchar *name = NULL;
 
 		gtk_tree_model_get(model, &iter,
-		                   PIDGIN_CONVERSATION_WINDOW_COLUMN_NAME, &name,
-		                   PIDGIN_CONVERSATION_WINDOW_COLUMN_OBJECT, &obj,
+		                   PIDGIN_DISPLAY_WINDOW_COLUMN_NAME, &name,
+		                   PIDGIN_DISPLAY_WINDOW_COLUMN_OBJECT, &obj,
 		                   -1);
 
 		gtk_stack_set_visible_child_name(GTK_STACK(window->stack), name);
@@ -314,24 +314,24 @@
 		 * actions.
 		 */
 		is_conversation = PURPLE_IS_CONVERSATION(obj);
-		pidgin_conversation_window_actions_set_enabled(G_ACTION_MAP(window),
-							       pidgin_conversation_window_conversation_actions,
+		pidgin_display_window_actions_set_enabled(G_ACTION_MAP(window),
+							       pidgin_display_window_conversation_actions,
 							       is_conversation);
 
 		/* If an IM is selected, enable the IM-specific actions otherwise
 		 * disable them.
 		 */
 		im_selected = PURPLE_IS_IM_CONVERSATION(obj);
-		pidgin_conversation_window_actions_set_enabled(G_ACTION_MAP(window),
-							       pidgin_conversation_window_im_conversation_actions,
+		pidgin_display_window_actions_set_enabled(G_ACTION_MAP(window),
+							       pidgin_display_window_im_conversation_actions,
 							       im_selected);
 
 		/* If a chat is selected, enable the chat-specific actions otherwise
 		 * disable them.
 		 */
 		chat_selected = PURPLE_IS_CHAT_CONVERSATION(obj);
-		pidgin_conversation_window_actions_set_enabled(G_ACTION_MAP(window),
-							       pidgin_conversation_window_chat_conversation_actions,
+		pidgin_display_window_actions_set_enabled(G_ACTION_MAP(window),
+							       pidgin_display_window_chat_conversation_actions,
 							       chat_selected);
 
 		g_clear_object(&obj);
@@ -343,13 +343,13 @@
 }
 
 static gboolean
-pidgin_conversation_window_key_pressed_cb(GtkEventControllerKey *controller,
-                                          guint keyval,
-                                          G_GNUC_UNUSED guint keycode,
-                                          GdkModifierType state,
-                                          gpointer data)
+pidgin_display_window_key_pressed_cb(GtkEventControllerKey *controller,
+                                     guint keyval,
+                                     G_GNUC_UNUSED guint keycode,
+                                     GdkModifierType state,
+                                     gpointer data)
 {
-	PidginConversationWindow *window = data;
+	PidginDisplayWindow *window = data;
 
 	/* If CTRL was held down... */
 	if (state & GDK_CONTROL_MASK) {
@@ -357,14 +357,14 @@
 			case GDK_KEY_Page_Down:
 			case GDK_KEY_KP_Page_Down:
 			case ']':
-				pidgin_conversation_window_select_next(window);
+				pidgin_display_window_select_next(window);
 				return TRUE;
 				break;
 
 			case GDK_KEY_Page_Up:
 			case GDK_KEY_KP_Page_Up:
 			case '[':
-				pidgin_conversation_window_select_previous(window);
+				pidgin_display_window_select_previous(window);
 				return TRUE;
 				break;
 		} /* End of switch */
@@ -374,7 +374,7 @@
 	else if (state & GDK_ALT_MASK) {
 		if ('1' <= keyval && keyval <= '9') {
 			guint switchto = keyval - '1';
-			pidgin_conversation_window_select_nth(window, switchto);
+			pidgin_display_window_select_nth(window, switchto);
 
 			return TRUE;
 		}
@@ -387,8 +387,8 @@
  * GObjectImplementation
  *****************************************************************************/
 static void
-pidgin_conversation_window_dispose(GObject *obj) {
-	PidginConversationWindow *window = PIDGIN_CONVERSATION_WINDOW(obj);
+pidgin_display_window_dispose(GObject *obj) {
+	PidginDisplayWindow *window = PIDGIN_DISPLAY_WINDOW(obj);
 
 	if(GTK_IS_TREE_MODEL(window->model)) {
 		GtkTreeModel *model = GTK_TREE_MODEL(window->model);
@@ -405,7 +405,7 @@
 				PurpleConversation *conversation = NULL;
 
 				gtk_tree_model_get(model, &iter,
-				                   PIDGIN_CONVERSATION_WINDOW_COLUMN_OBJECT, &conversation,
+				                   PIDGIN_DISPLAY_WINDOW_COLUMN_OBJECT, &conversation,
 				                   -1);
 
 				if(PURPLE_IS_CONVERSATION(conversation)) {
@@ -419,11 +419,11 @@
 		g_clear_pointer(&window->conversation_path, gtk_tree_path_free);
 	}
 
-	G_OBJECT_CLASS(pidgin_conversation_window_parent_class)->dispose(obj);
+	G_OBJECT_CLASS(pidgin_display_window_parent_class)->dispose(obj);
 }
 
 static void
-pidgin_conversation_window_init(PidginConversationWindow *window) {
+pidgin_display_window_init(PidginDisplayWindow *window) {
 	GtkEventController *key = NULL;
 	GtkTreeIter iter;
 
@@ -438,22 +438,22 @@
 	key = gtk_event_controller_key_new();
 	gtk_event_controller_set_propagation_phase(key, GTK_PHASE_CAPTURE);
 	g_signal_connect(G_OBJECT(key), "key-pressed",
-	                 G_CALLBACK(pidgin_conversation_window_key_pressed_cb),
+	                 G_CALLBACK(pidgin_display_window_key_pressed_cb),
 	                 window);
 	gtk_widget_add_controller(GTK_WIDGET(window), key);
 
 	/* Add our toplevels to the tree store. */
 	gtk_tree_store_append(window->model, &iter, NULL);
 	gtk_tree_store_set(window->model, &iter,
-	                   PIDGIN_CONVERSATION_WINDOW_COLUMN_OBJECT, window->notification_list,
-	                   PIDGIN_CONVERSATION_WINDOW_COLUMN_NAME, "__notifications__",
-	                   PIDGIN_CONVERSATION_WINDOW_COLUMN_MARKUP, _("Notifications"),
+	                   PIDGIN_DISPLAY_WINDOW_COLUMN_OBJECT, window->notification_list,
+	                   PIDGIN_DISPLAY_WINDOW_COLUMN_NAME, "__notifications__",
+	                   PIDGIN_DISPLAY_WINDOW_COLUMN_MARKUP, _("Notifications"),
 	                   -1);
 
 	gtk_tree_store_append(window->model, &iter, NULL);
 	gtk_tree_store_set(window->model, &iter,
-	                   PIDGIN_CONVERSATION_WINDOW_COLUMN_MARKUP, _("Conversations"),
-	                   PIDGIN_CONVERSATION_WINDOW_COLUMN_NAME, "__conversations__",
+	                   PIDGIN_DISPLAY_WINDOW_COLUMN_MARKUP, _("Conversations"),
+	                   PIDGIN_DISPLAY_WINDOW_COLUMN_NAME, "__conversations__",
 	                   -1);
 	gtk_tree_selection_select_iter(window->selection, &iter);
 	window->conversation_path = gtk_tree_model_get_path(GTK_TREE_MODEL(window->model),
@@ -461,14 +461,14 @@
 }
 
 static void
-pidgin_conversation_window_class_init(PidginConversationWindowClass *klass) {
+pidgin_display_window_class_init(PidginDisplayWindowClass *klass) {
 	GObjectClass *obj_class = G_OBJECT_CLASS(klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(klass);
 
-	obj_class->dispose = pidgin_conversation_window_dispose;
+	obj_class->dispose = pidgin_display_window_dispose;
 
 	/**
-	 * PidginConversationWindow::conversation-switched:
+	 * PidginDisplayWindow::conversation-switched:
 	 * @window: The conversation window.
 	 * @new_conv: The now active conversation.
 	 *
@@ -492,35 +492,35 @@
 	    "/im/pidgin/Pidgin3/Conversations/window.ui"
 	);
 
-	gtk_widget_class_bind_template_child(widget_class, PidginConversationWindow,
+	gtk_widget_class_bind_template_child(widget_class, PidginDisplayWindow,
 	                                     vbox);
 
-	gtk_widget_class_bind_template_child(widget_class, PidginConversationWindow,
+	gtk_widget_class_bind_template_child(widget_class, PidginDisplayWindow,
 	                                     model);
-	gtk_widget_class_bind_template_child(widget_class, PidginConversationWindow,
+	gtk_widget_class_bind_template_child(widget_class, PidginDisplayWindow,
 	                                     view);
-	gtk_widget_class_bind_template_child(widget_class, PidginConversationWindow,
+	gtk_widget_class_bind_template_child(widget_class, PidginDisplayWindow,
 	                                     selection);
 
-	gtk_widget_class_bind_template_child(widget_class, PidginConversationWindow,
+	gtk_widget_class_bind_template_child(widget_class, PidginDisplayWindow,
 	                                     stack);
-	gtk_widget_class_bind_template_child(widget_class, PidginConversationWindow,
+	gtk_widget_class_bind_template_child(widget_class, PidginDisplayWindow,
 	                                     notification_list);
 
 	gtk_widget_class_bind_template_callback(widget_class,
-	                                        pidgin_conversation_window_selection_changed);
+	                                        pidgin_display_window_selection_changed);
 
 	gtk_widget_class_bind_template_callback(widget_class,
-	                                        pidgin_conversation_window_key_pressed_cb);
+	                                        pidgin_display_window_key_pressed_cb);
 }
 
 /******************************************************************************
  * API
  *****************************************************************************/
 GtkWidget *
-pidgin_conversation_window_get_default(void) {
+pidgin_display_window_get_default(void) {
 	if(!GTK_IS_WIDGET(default_window)) {
-		default_window = pidgin_conversation_window_new();
+		default_window = pidgin_display_window_new();
 		g_object_add_weak_pointer(G_OBJECT(default_window),
 		                          (gpointer)&default_window);
 	}
@@ -529,16 +529,16 @@
 }
 
 GtkWidget *
-pidgin_conversation_window_new(void) {
+pidgin_display_window_new(void) {
 	return g_object_new(
-		PIDGIN_TYPE_CONVERSATION_WINDOW,
+		PIDGIN_TYPE_DISPLAY_WINDOW,
 		"show-menubar", TRUE,
 		NULL);
 }
 
 void
-pidgin_conversation_window_add(PidginConversationWindow *window,
-                               PurpleConversation *conversation)
+pidgin_display_window_add(PidginDisplayWindow *window,
+                          PurpleConversation *conversation)
 {
 	PidginConversation *gtkconv = NULL;
 	GtkTreeIter parent, iter;
@@ -546,7 +546,7 @@
 	const gchar *markup = NULL;
 	gboolean expand = FALSE;
 
-	g_return_if_fail(PIDGIN_IS_CONVERSATION_WINDOW(window));
+	g_return_if_fail(PIDGIN_IS_DISPLAY_WINDOW(window));
 	g_return_if_fail(PURPLE_IS_CONVERSATION(conversation));
 
 	model = GTK_TREE_MODEL(window->model);
@@ -582,9 +582,9 @@
 
 	gtk_tree_store_prepend(window->model, &iter, &parent);
 	gtk_tree_store_set(window->model, &iter,
-	                   PIDGIN_CONVERSATION_WINDOW_COLUMN_OBJECT, conversation,
-	                   PIDGIN_CONVERSATION_WINDOW_COLUMN_NAME, markup,
-	                   PIDGIN_CONVERSATION_WINDOW_COLUMN_MARKUP, markup,
+	                   PIDGIN_DISPLAY_WINDOW_COLUMN_OBJECT, conversation,
+	                   PIDGIN_DISPLAY_WINDOW_COLUMN_NAME, markup,
+	                   PIDGIN_DISPLAY_WINDOW_COLUMN_MARKUP, markup,
 	                   -1);
 
 	/* If we just added the first child, expand the parent. */
@@ -600,14 +600,14 @@
 }
 
 void
-pidgin_conversation_window_remove(PidginConversationWindow *window,
-                                  PurpleConversation *conversation)
+pidgin_display_window_remove(PidginDisplayWindow *window,
+                             PurpleConversation *conversation)
 {
 	GtkTreeIter parent, iter;
 	GtkTreeModel *model = NULL;
 	GObject *obj = NULL;
 
-	g_return_if_fail(PIDGIN_IS_CONVERSATION_WINDOW(window));
+	g_return_if_fail(PIDGIN_IS_DISPLAY_WINDOW(window));
 	g_return_if_fail(PURPLE_IS_CONVERSATION(conversation));
 
 	model = GTK_TREE_MODEL(window->model);
@@ -624,7 +624,7 @@
 
 	do {
 		gtk_tree_model_get(model, &iter,
-		                   PIDGIN_CONVERSATION_WINDOW_COLUMN_OBJECT, &obj,
+		                   PIDGIN_DISPLAY_WINDOW_COLUMN_OBJECT, &obj,
 		                   -1);
 
 		if(PURPLE_CONVERSATION(obj) == conversation) {
@@ -650,11 +650,11 @@
 }
 
 guint
-pidgin_conversation_window_get_count(PidginConversationWindow *window) {
+pidgin_display_window_get_count(PidginDisplayWindow *window) {
 	GtkSelectionModel *model = NULL;
 	guint count = 0;
 
-	g_return_val_if_fail(PIDGIN_IS_CONVERSATION_WINDOW(window), 0);
+	g_return_val_if_fail(PIDGIN_IS_DISPLAY_WINDOW(window), 0);
 
 	model = gtk_stack_get_pages(GTK_STACK(window->stack));
 
@@ -666,18 +666,18 @@
 }
 
 PurpleConversation *
-pidgin_conversation_window_get_selected(PidginConversationWindow *window) {
+pidgin_display_window_get_selected(PidginDisplayWindow *window) {
 	PurpleConversation *conversation = NULL;
 	GtkTreeSelection *selection = NULL;
 	GtkTreeIter iter;
 
-	g_return_val_if_fail(PIDGIN_IS_CONVERSATION_WINDOW(window), NULL);
+	g_return_val_if_fail(PIDGIN_IS_DISPLAY_WINDOW(window), NULL);
 
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(window->view));
 	if(gtk_tree_selection_get_selected(selection, NULL, &iter)) {
 
 		gtk_tree_model_get(GTK_TREE_MODEL(window->model), &iter,
-		                   PIDGIN_CONVERSATION_WINDOW_COLUMN_OBJECT, &conversation,
+		                   PIDGIN_DISPLAY_WINDOW_COLUMN_OBJECT, &conversation,
 		                   -1);
 	}
 
@@ -685,12 +685,12 @@
 }
 
 void
-pidgin_conversation_window_select(PidginConversationWindow *window,
-                                  PurpleConversation *conversation)
+pidgin_display_window_select(PidginDisplayWindow *window,
+                             PurpleConversation *conversation)
 {
 	const gchar *name = NULL;
 
-	g_return_if_fail(PIDGIN_IS_CONVERSATION_WINDOW(window));
+	g_return_if_fail(PIDGIN_IS_DISPLAY_WINDOW(window));
 	g_return_if_fail(PURPLE_IS_CONVERSATION(conversation));
 
 	name = purple_conversation_get_name(conversation);
@@ -698,13 +698,13 @@
 }
 
 void
-pidgin_conversation_window_select_previous(PidginConversationWindow *window) {
+pidgin_display_window_select_previous(PidginDisplayWindow *window) {
 	GtkTreeIter iter;
 	GtkTreeModel *model = NULL;
 	GtkTreeSelection *selection = NULL;
 	gboolean set = FALSE;
 
-	g_return_if_fail(PIDGIN_IS_CONVERSATION_WINDOW(window));
+	g_return_if_fail(PIDGIN_IS_DISPLAY_WINDOW(window));
 
 	model = GTK_TREE_MODEL(window->model);
 
@@ -717,19 +717,19 @@
 	}
 
 	if(!set) {
-		pidgin_conversation_window_select_last(window);
+		pidgin_display_window_select_last(window);
 	}
 }
 
 
 void
-pidgin_conversation_window_select_next(PidginConversationWindow *window) {
+pidgin_display_window_select_next(PidginDisplayWindow *window) {
 	GtkTreeIter iter;
 	GtkTreeModel *model = NULL;
 	GtkTreeSelection *selection = NULL;
 	gboolean set = FALSE;
 
-	g_return_if_fail(PIDGIN_IS_CONVERSATION_WINDOW(window));
+	g_return_if_fail(PIDGIN_IS_DISPLAY_WINDOW(window));
 
 	model = GTK_TREE_MODEL(window->model);
 
@@ -742,16 +742,16 @@
 	}
 
 	if(!set) {
-		pidgin_conversation_window_select_first(window);
+		pidgin_display_window_select_first(window);
 	}
 }
 
 void
-pidgin_conversation_window_select_first(PidginConversationWindow *window) {
+pidgin_display_window_select_first(PidginDisplayWindow *window) {
 	GtkTreeIter iter;
 	GtkTreeModel *model = NULL;
 
-	g_return_if_fail(PIDGIN_IS_CONVERSATION_WINDOW(window));
+	g_return_if_fail(PIDGIN_IS_DISPLAY_WINDOW(window));
 
 	model = GTK_TREE_MODEL(window->model);
 
@@ -764,12 +764,12 @@
 }
 
 void
-pidgin_conversation_window_select_last(PidginConversationWindow *window) {
+pidgin_display_window_select_last(PidginDisplayWindow *window) {
 	GtkTreeIter iter;
 	GtkTreeModel *model = NULL;
 	gint count = 0;
 
-	g_return_if_fail(PIDGIN_IS_CONVERSATION_WINDOW(window));
+	g_return_if_fail(PIDGIN_IS_DISPLAY_WINDOW(window));
 
 	model = GTK_TREE_MODEL(window->model);
 	count = gtk_tree_model_iter_n_children(model, NULL);
@@ -783,13 +783,13 @@
 }
 
 void
-pidgin_conversation_window_select_nth(PidginConversationWindow *window,
-                                      guint nth)
+pidgin_display_window_select_nth(PidginDisplayWindow *window,
+                                 guint nth)
 {
 	GtkTreeIter iter;
 	GtkTreeModel *model = NULL;
 
-	g_return_if_fail(PIDGIN_IS_CONVERSATION_WINDOW(window));
+	g_return_if_fail(PIDGIN_IS_DISPLAY_WINDOW(window));
 
 	model = GTK_TREE_MODEL(window->model);
 
@@ -802,12 +802,12 @@
 }
 
 gboolean
-pidgin_conversation_window_conversation_is_selected(PidginConversationWindow *window,
-                                                    PurpleConversation *conversation)
+pidgin_display_window_conversation_is_selected(PidginDisplayWindow *window,
+                                               PurpleConversation *conversation)
 {
 	const gchar *name = NULL, *visible = NULL;
 
-	g_return_val_if_fail(PIDGIN_IS_CONVERSATION_WINDOW(window), FALSE);
+	g_return_val_if_fail(PIDGIN_IS_DISPLAY_WINDOW(window), FALSE);
 	g_return_val_if_fail(PURPLE_IS_CONVERSATION(conversation), FALSE);
 
 	name = purple_conversation_get_name(conversation);
diff --git a/pidgin/plugins/gestures/gestures.c b/pidgin/plugins/gestures/gestures.c
--- a/pidgin/plugins/gestures/gestures.c
+++ b/pidgin/plugins/gestures/gestures.c
@@ -58,7 +58,7 @@
 	gtkconv = PIDGIN_CONVERSATION(conv);
 	win = gtk_widget_get_toplevel(gtkconv->tab_cont);
 
-	pidgin_conversation_window_select_previous(PIDGIN_CONVERSATION_WINDOW(win));
+	pidgin_display_window_select_previous(PIDGIN_DISPLAY_WINDOW(win));
 }
 
 static void
@@ -72,7 +72,7 @@
 	gtkconv = PIDGIN_CONVERSATION(conv);
 	win = gtk_widget_get_toplevel(gtkconv->tab_cont);
 
-	pidgin_conversation_window_select_next(PIDGIN_CONVERSATION_WINDOW(win));
+	pidgin_display_window_select_next(PIDGIN_DISPLAY_WINDOW(win));
 }
 
 static void
@@ -84,15 +84,15 @@
 	conv    = (PurpleConversation *)data;
 	old_win = gtk_widget_get_parent(PIDGIN_CONVERSATION(conv)->tab_cont);
 
-	if(pidgin_conversation_window_get_count(PIDGIN_CONVERSATION_WINDOW(old_win)) <= 1) {
+	if(pidgin_display_window_get_count(PIDGIN_DISPLAY_WINDOW(old_win)) <= 1) {
 		return;
 	}
 
-	new_win = pidgin_conversation_window_new();
+	new_win = pidgin_display_window_new();
 
-	pidgin_conversation_window_remove(PIDGIN_CONVERSATION_WINDOW(old_win),
+	pidgin_display_window_remove(PIDGIN_DISPLAY_WINDOW(old_win),
 	                                  conv);
-	pidgin_conversation_window_add(PIDGIN_CONVERSATION_WINDOW(new_win), conv);
+	pidgin_display_window_add(PIDGIN_DISPLAY_WINDOW(new_win), conv);
 
 	gtk_widget_show_all(new_win);
 }
diff --git a/pidgin/plugins/notify/notify.c b/pidgin/plugins/notify/notify.c
--- a/pidgin/plugins/notify/notify.c
+++ b/pidgin/plugins/notify/notify.c
@@ -208,7 +208,7 @@
 unnotify(PurpleConversation *conv, gboolean reset)
 {
 	PurpleConversation *active_conv = NULL;
-	PidginConversationWindow *purplewin = NULL;
+	PidginDisplayWindow *displaywin = NULL;
 	GtkWidget *win;
 
 	g_return_if_fail(conv != NULL);
@@ -216,9 +216,9 @@
 		return;
 
 	win = gtk_widget_get_toplevel(PIDGIN_CONVERSATION(conv)->tab_cont);
-	purplewin = PIDGIN_CONVERSATION_WINDOW(win);
+	displaywin = PIDGIN_DISPLAY_WINDOW(win);
 
-	activate_conv = pidgin_conversation_window_get_selected(purplewin);
+	activate_conv = pidgin_display_window_get_selected(purplewin);
 
 	/* reset the conversation window title */
 	purple_conversation_autoset_title(active_conv);
diff --git a/pidgin/plugins/transparency/transparency.c b/pidgin/plugins/transparency/transparency.c
--- a/pidgin/plugins/transparency/transparency.c
+++ b/pidgin/plugins/transparency/transparency.c
@@ -168,7 +168,7 @@
 conversation_delete_cb(G_GNUC_UNUSED GtkApplication *application,
                        GtkWindow *window, G_GNUC_UNUSED gpointer data)
 {
-	if(!PIDGIN_IS_CONVERSATION_WINDOW(window)) {
+	if(!PIDGIN_IS_DISPLAY_WINDOW(window)) {
 		return;
 	}
 
@@ -273,7 +273,7 @@
 	for(; wins; wins = wins->next) {
 		GtkWidget *window = wins->data;
 
-		if(!PIDGIN_IS_CONVERSATION_WINDOW(window)) {
+		if(!PIDGIN_IS_DISPLAY_WINDOW(window)) {
 			continue;
 		}
 
@@ -316,7 +316,7 @@
 		for(; wins; wins = wins->next) {
 			GtkWidget *win = wins->data;
 
-			if(!PIDGIN_IS_CONVERSATION_WINDOW(win)) {
+			if(!PIDGIN_IS_DISPLAY_WINDOW(win)) {
 				continue;
 			}
 
@@ -335,7 +335,7 @@
 new_conversation_cb(G_GNUC_UNUSED GtkApplication *application,
                     GtkWindow *window, G_GNUC_UNUSED gpointer data)
 {
-	if(!PIDGIN_IS_CONVERSATION_WINDOW(window)) {
+	if(!PIDGIN_IS_DISPLAY_WINDOW(window)) {
 		return;
 	}
 
@@ -378,7 +378,7 @@
 	for(; wins; wins = wins->next) {
 		GtkWidget *window = wins->data;
 
-		if(!PIDGIN_IS_CONVERSATION_WINDOW(window)) {
+		if(!PIDGIN_IS_DISPLAY_WINDOW(window)) {
 			continue;
 		}
 
@@ -416,7 +416,7 @@
 	for(; wins; wins = wins->next) {
 		GtkWidget *window = wins->data;
 
-		if(!PIDGIN_IS_CONVERSATION_WINDOW(window)) {
+		if(!PIDGIN_IS_DISPLAY_WINDOW(window)) {
 			continue;
 		}
 
diff --git a/pidgin/plugins/unity/unity.c b/pidgin/plugins/unity/unity.c
--- a/pidgin/plugins/unity/unity.c
+++ b/pidgin/plugins/unity/unity.c
@@ -150,7 +150,7 @@
 {
 	gint count;
 	PidginConversation *gtkconv = NULL;
-	PidginConversationWindow *convwin = NULL;
+	PidginDisplayWindow *displaywin = NULL;
 	GtkRoot *root = NULL;
 	GtkWidget *win = NULL;
 
@@ -160,10 +160,10 @@
 	gtkconv = PIDGIN_CONVERSATION(conv);
 	root = gtk_widget_get_root(gtkconv->tab_cont);
 	win = GTK_WIDGET(root);
-	convwin = PIDGIN_CONVERSATION_WINDOW(win);
+	displaywin = PIDGIN_DISPLAY_WINDOW(win);
 
 	if (!gtk_widget_has_focus(win) ||
-		!pidgin_conversation_window_conversation_is_selected(convwin, conv))
+		!pidgin_display_window_conversation_is_selected(displaywin, conv))
 	{
 		count = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(conv),
 				"unity-message-count"));
@@ -289,15 +289,15 @@
 	if (conv) {
 		GtkRoot *root = NULL;
 		GtkWidget *win = NULL;
-		PidginConversationWindow *convwin = NULL;
+		PidginDisplayWindow *displaywin = NULL;
 
 		root = gtk_widget_get_root(PIDGIN_CONVERSATION(conv)->tab_cont);
 		win = GTK_WIDGET(root);
-		convwin = PIDGIN_CONVERSATION_WINDOW(win);
+		displaywin = PIDGIN_DISPLAY_WINDOW(win);
 
 		unalert(conv);
 
-		pidgin_conversation_window_select(convwin, conv);
+		pidgin_display_window_select(displaywin, conv);
 
 		gtk_root_set_focus(root, PIDGIN_CONVERSATION(conv)->entry);
 	}
diff --git a/pidgin/resources/Conversations/window.ui b/pidgin/resources/Conversations/window.ui
--- a/pidgin/resources/Conversations/window.ui
+++ b/pidgin/resources/Conversations/window.ui
@@ -36,14 +36,14 @@
       <column type="gchararray"/>
     </columns>
   </object>
-  <template class="PidginConversationWindow" parent="GtkApplicationWindow">
+  <template class="PidginDisplayWindow" parent="GtkApplicationWindow">
     <property name="show-menubar">1</property>
     <property name="default-height">450</property>
     <property name="default-width">950</property>
     <child>
       <object class="GtkEventControllerKey">
         <property name="propagation-phase">capture</property>
-        <signal name="key-pressed" handler="pidgin_conversation_window_key_pressed_cb"/>
+        <signal name="key-pressed" handler="pidgin_display_window_key_pressed_cb"/>
       </object>
     </child>
     <child>
@@ -79,7 +79,7 @@
                         <child internal-child="selection">
                           <object class="GtkTreeSelection" id="selection">
                             <property name="mode">browse</property>
-                            <signal name="changed" handler="pidgin_conversation_window_selection_changed" object="PidginConversationWindow" swapped="no"/>
+                            <signal name="changed" handler="pidgin_display_window_selection_changed" object="PidginDisplayWindow" swapped="no"/>
                           </object>
                         </child>
                         <child>

diff --git a/pidgin/pidginconversationwindow.h b/pidgin/pidginconversationwindow.h
--- a/pidgin/pidginconversationwindow.h
+++ b/pidgin/pidginconversationwindow.h
@@ -24,8 +24,8 @@
 # error "only <pidgin.h> may be included directly"
 #endif
 
-#ifndef PIDGIN_CONVERSATION_WINDOW_H
-#define PIDGIN_CONVERSATION_WINDOW_H
+#ifndef PIDGIN_DISPLAY_WINDOW_H
+#define PIDGIN_DISPLAY_WINDOW_H
 
 #include <glib.h>
 
@@ -36,40 +36,40 @@
 G_BEGIN_DECLS
 
 /**
- * PidginConversationWindow:
+ * PidginDisplayWindow:
  *
  * #PidginConversationWindow is a widget that contains #PidginConversations.
  *
  * Since: 3.0.0
  */
 
-#define PIDGIN_TYPE_CONVERSATION_WINDOW (pidgin_conversation_window_get_type())
-G_DECLARE_FINAL_TYPE(PidginConversationWindow, pidgin_conversation_window,
-                     PIDGIN, CONVERSATION_WINDOW, GtkApplicationWindow)
+#define PIDGIN_TYPE_DISPLAY_WINDOW (pidgin_display_window_get_type())
+G_DECLARE_FINAL_TYPE(PidginDisplayWindow, pidgin_display_window,
+                     PIDGIN, DISPLAY_WINDOW, GtkApplicationWindow)
 
 /**
- * pidgin_conversation_window_new:
+ * pidgin_display_window_new:
  *
  * Creates a new #PidginConversationWindow instance.
  *
  * Returns: (transfer full): The new #PidginConversationWindow instance.
  */
-GtkWidget *pidgin_conversation_window_new(void);
+GtkWidget *pidgin_display_window_new(void);
 
 /**
- * pidgin_conversation_window_get_default:
+ * pidgin_display_window_get_default:
  *
  * Gets or creates the default conversation window.
  *
  * Returns: (transfer none): The default #PidginConversationWindow.
  *
  * Since: 3.0.0
  */
-GtkWidget *pidgin_conversation_window_get_default(void);
+GtkWidget *pidgin_display_window_get_default(void);
 
 /**
- * pidgin_conversation_window_add:
- * @window: The #PidginConversationWindow instance.
+ * pidgin_display_window_add:
+ * @window: The #PidginDisplayWindow instance.
  * @conversation: The #PurpleConversation to add to @window.
  *
  * Adds @conversation to @window. If @conversation is already in @window, this
@@ -77,11 +77,11 @@
  *
  * Since: 3.0.0
  */
-void pidgin_conversation_window_add(PidginConversationWindow *window, PurpleConversation *conversation);
+void pidgin_display_window_add(PidginDisplayWindow *window, PurpleConversation *conversation);
 
 /**
- * pidgin_conversation_window_remove:
- * @window: The #PidginConversationWindow instance.
+ * pidgin_display_window_remove:
+ * @window: The #PidginDisplayWindow instance.
  * @conversation: The #PurpleConversation to remove from @window.
  *
  * Removes @conversation from @window. If @conversation is not in @window, this
@@ -89,10 +89,10 @@
  *
  * Since: 3.0.0
  */
-void pidgin_conversation_window_remove(PidginConversationWindow *window, PurpleConversation *conversation);
+void pidgin_display_window_remove(PidginDisplayWindow *window, PurpleConversation *conversation);
 
 /**
- * pidgin_conversation_window_get_count:
+ * pidgin_display_window_get_count:
  * @window: The conversation window instance.
  *
  * Gets the number of conversations that @window contains.
@@ -101,10 +101,10 @@
  *
  * Since: 3.0.0
  */
-guint pidgin_conversation_window_get_count(PidginConversationWindow *window);
+guint pidgin_display_window_get_count(PidginDisplayWindow *window);
 
 /**
- * pidgin_conversation_window_get_selected:
+ * pidgin_display_window_get_selected:
  * @window: The conversation window instance.
  *
  * Gets the currently selected PurpleConversation or %NULL if there is no
@@ -114,10 +114,10 @@
  *
  * Since: 3.0.0
  */
-PurpleConversation *pidgin_conversation_window_get_selected(PidginConversationWindow *window);
+PurpleConversation *pidgin_display_window_get_selected(PidginDisplayWindow *window);
 
 /**
- * pidgin_conversation_window_select:
+ * pidgin_display_window_select:
  * @window: The conversation window instance.
  * @conversation: The conversation to select.
  *
@@ -125,10 +125,10 @@
  *
  * Since: 3.0.0
  */
-void pidgin_conversation_window_select(PidginConversationWindow *window, PurpleConversation *conversation);
+void pidgin_display_window_select(PidginDisplayWindow *window, PurpleConversation *conversation);
 
 /**
- * pidgin_conversation_window_select_previous:
+ * pidgin_display_window_select_previous:
  * @window: The conversation window instance.
  *
  * Switches to the conversation previous to the currently selected
@@ -138,10 +138,10 @@
  *
  * Since: 3.0.0
  */
-void pidgin_conversation_window_select_previous(PidginConversationWindow *window);
+void pidgin_display_window_select_previous(PidginDisplayWindow *window);
 
 /**
- * pidgin_conversation_window_select_next:
+ * pidgin_display_window_select_next:
  * @window: The conversation window instance.
  *
  * Switches to the conversation next of the currently selected conversation.
@@ -150,10 +150,10 @@
  *
  * Since: 3.0.0
  */
-void pidgin_conversation_window_select_next(PidginConversationWindow *window);
+void pidgin_display_window_select_next(PidginDisplayWindow *window);
 
 /**
- * pidgin_conversation_window_select_first:
+ * pidgin_display_window_select_first:
  * @window: The conversation window instance.
  *
  * Selects the first conversation in @window. If there are no conversations in
@@ -161,10 +161,10 @@
  *
  * Since: 3.0.0
  */
-void pidgin_conversation_window_select_first(PidginConversationWindow *window);
+void pidgin_display_window_select_first(PidginDisplayWindow *window);
 
 /**
- * pidgin_conversation_window_select_last:
+ * pidgin_display_window_select_last:
  * @window: The conversation window instance.
  *
  * Selects the last conversation in @window. If there are no conversations in
@@ -172,10 +172,10 @@
  *
  * Since: 3.0.0
  */
-void pidgin_conversation_window_select_last(PidginConversationWindow *window);
+void pidgin_display_window_select_last(PidginDisplayWindow *window);
 
 /**
- * pidgin_conversation_window_select_nth:
+ * pidgin_display_window_select_nth:
  * @window: The conversation window instance.
  * @nth: The index of the conversation to switch to.
  *
@@ -184,10 +184,10 @@
  *
  * Since: 3.0.0
  */
-void pidgin_conversation_window_select_nth(PidginConversationWindow *window, guint nth);
+void pidgin_display_window_select_nth(PidginDisplayWindow *window, guint nth);
 
 /**
- * pidgin_conversation_window_conversation_is_selected:
+ * pidgin_display_window_conversation_is_selected:
  * @window: The conversation window instance.
  * @conversation: The conversation instance.
  *
@@ -197,8 +197,8 @@
  *
  * Since: 3.0.0
  */
-gboolean pidgin_conversation_window_conversation_is_selected(PidginConversationWindow *window, PurpleConversation *conversation);
+gboolean pidgin_display_window_conversation_is_selected(PidginDisplayWindow *window, PurpleConversation *conversation);
 
 G_END_DECLS
 
-#endif /* PIDGIN_CONVERSATION_WINDOW_H */
+#endif /* PIDGIN_DISPLAY_WINDOW_H */
@@ -36,40 +36,40 @@
  *
- * #PidginConversationWindow is a widget that contains #PidginConversations.
+ * #PidginDisplayWindow is a widget that contains #PidginConversations.
  *
  * Since: 3.0.0
@@ -36,40 +36,40 @@
  *
- * Creates a new #PidginConversationWindow instance.
+ * Creates a new #PidginDisplayWindow instance.
  *
@@ -36,40 +36,40 @@
  *
- * Returns: (transfer full): The new #PidginConversationWindow instance.
+ * Returns: (transfer full): The new #PidginDisplayWindow instance.
  */
@@ -36,40 +36,40 @@
  * Gets or creates the default conversation window.
  *
- * Returns: (transfer none): The default #PidginConversationWindow.
+ * Returns: (transfer none): The default #PidginDisplayWindow.
  *
  * Since: 3.0.0